# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dota_gcmessages_client_watch.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import dota2.protobufs.dota_shared_enums_pb2 as dota__shared__enums__pb2
import dota2.protobufs.dota_gcmessages_common_pb2 as dota__gcmessages__common__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='dota_gcmessages_client_watch.proto',
  package='',
  syntax='proto2',
  serialized_pb=_b('\n\"dota_gcmessages_client_watch.proto\x1a\x17\x64ota_shared_enums.proto\x1a\x1c\x64ota_gcmessages_common.proto\"\xd2\x05\n\x12\x43SourceTVGameSmall\x12\x15\n\ractivate_time\x18\x01 \x01(\r\x12\x17\n\x0f\x64\x65\x61\x63tivate_time\x18\x02 \x01(\r\x12\x17\n\x0fserver_steam_id\x18\x03 \x01(\x04\x12\x10\n\x08lobby_id\x18\x04 \x01(\x04\x12\x11\n\tleague_id\x18\x05 \x01(\r\x12\x12\n\nlobby_type\x18\x06 \x01(\r\x12\x11\n\tgame_time\x18\x07 \x01(\x05\x12\r\n\x05\x64\x65lay\x18\x08 \x01(\r\x12\x12\n\nspectators\x18\t \x01(\r\x12\x11\n\tgame_mode\x18\n \x01(\r\x12\x13\n\x0b\x61verage_mmr\x18\x0b \x01(\r\x12\x19\n\x11team_name_radiant\x18\x0f \x01(\t\x12\x16\n\x0eteam_name_dire\x18\x10 \x01(\t\x12\x19\n\x11team_logo_radiant\x18\x18 \x01(\x06\x12\x16\n\x0eteam_logo_dire\x18\x19 \x01(\x06\x12\x12\n\nsort_score\x18\x11 \x01(\r\x12\x18\n\x10last_update_time\x18\x12 \x01(\x02\x12\x14\n\x0cradiant_lead\x18\x13 \x01(\x05\x12\x15\n\rradiant_score\x18\x14 \x01(\r\x12\x12\n\ndire_score\x18\x15 \x01(\r\x12+\n\x07players\x18\x16 \x03(\x0b\x32\x1a.CSourceTVGameSmall.Player\x12\x16\n\x0e\x62uilding_state\x18\x17 \x01(\x07\x12%\n\x1dweekend_tourney_tournament_id\x18\x1a \x01(\r\x12 \n\x18weekend_tourney_division\x18\x1b \x01(\r\x12#\n\x1bweekend_tourney_skill_level\x18\x1c \x01(\r\x12%\n\x1dweekend_tourney_bracket_round\x18\x1d \x01(\r\x1a-\n\x06Player\x12\x12\n\naccount_id\x18\x01 \x01(\r\x12\x0f\n\x07hero_id\x18\x02 \x01(\r\"\x9c\x01\n\"CMsgClientToGCFindTopSourceTVGames\x12\x12\n\nsearch_key\x18\x01 \x01(\t\x12\x11\n\tleague_id\x18\x02 \x01(\r\x12\x0f\n\x07hero_id\x18\x03 \x01(\r\x12\x12\n\nstart_game\x18\x04 \x01(\r\x12\x17\n\x0fgame_list_index\x18\x05 \x01(\r\x12\x11\n\tlobby_ids\x18\x06 \x03(\x04\"\xe4\x01\n*CMsgGCToClientFindTopSourceTVGamesResponse\x12\x12\n\nsearch_key\x18\x01 \x01(\t\x12\x11\n\tleague_id\x18\x02 \x01(\r\x12\x0f\n\x07hero_id\x18\x03 \x01(\r\x12\x12\n\nstart_game\x18\x04 \x01(\r\x12\x11\n\tnum_games\x18\x05 \x01(\r\x12\x17\n\x0fgame_list_index\x18\x06 \x01(\r\x12&\n\tgame_list\x18\x07 \x03(\x0b\x32\x13.CSourceTVGameSmall\x12\x16\n\x0especific_games\x18\x08 \x01(\x08\"O\n$CMsgGCToClientTopWeekendTourneyGames\x12\'\n\nlive_games\x18\x01 \x03(\x0b\x32\x13.CSourceTVGameSmall\"^\n\x1f\x43MsgClientToGCTopMatchesRequest\x12\x0f\n\x07hero_id\x18\x01 \x01(\r\x12\x19\n\x11player_account_id\x18\x02 \x01(\r\x12\x0f\n\x07team_id\x18\x03 \x01(\r\"\'\n%CMsgClientToGCTopLeagueMatchesRequest\"\'\n%CMsgClientToGCTopFriendMatchesRequest\"8\n#CMsgClientToGCMatchesMinimalRequest\x12\x11\n\tmatch_ids\x18\x01 \x03(\x04\"b\n$CMsgClientToGCMatchesMinimalResponse\x12&\n\x07matches\x18\x01 \x03(\x0b\x32\x15.CMsgDOTAMatchMinimal\x12\x12\n\nlast_match\x18\x02 \x01(\x08\"P\n&CMsgGCToClientTopLeagueMatchesResponse\x12&\n\x07matches\x18\x02 \x03(\x0b\x32\x15.CMsgDOTAMatchMinimal\"P\n&CMsgGCToClientTopFriendMatchesResponse\x12&\n\x07matches\x18\x01 \x03(\x0b\x32\x15.CMsgDOTAMatchMinimal\"\x93\x01\n\x1c\x43MsgClientToGCFindTopMatches\x12\x12\n\nstart_game\x18\x01 \x01(\r\x12\x11\n\tleague_id\x18\x02 \x01(\r\x12\x0f\n\x07hero_id\x18\x03 \x01(\r\x12\x11\n\tfriend_id\x18\x04 \x01(\r\x12\x13\n\x0b\x66riend_list\x18\x05 \x01(\x08\x12\x13\n\x0bleague_list\x18\x06 \x01(\x08\"\x98\x01\n*CMsgGCToClientFindTopLeagueMatchesResponse\x12\x12\n\nstart_game\x18\x01 \x01(\r\x12\x11\n\tleague_id\x18\x02 \x01(\r\x12\x0f\n\x07hero_id\x18\x03 \x01(\r\x12\x11\n\tmatch_ids\x18\x04 \x03(\r\x12\x1f\n\x07matches\x18\x05 \x03(\x0b\x32\x0e.CMsgDOTAMatch\"*\n\x16\x43MsgSpectateFriendGame\x12\x10\n\x08steam_id\x18\x01 \x01(\x06\"8\n\x1e\x43MsgSpectateFriendGameResponse\x12\x16\n\x0eserver_steamid\x18\x04 \x01(\x06\"\x9e\x06\n\x14\x43MsgDOTAMatchMinimal\x12\x10\n\x08match_id\x18\x01 \x01(\x04\x12\x12\n\nstart_time\x18\x02 \x01(\x07\x12\x10\n\x08\x64uration\x18\x03 \x01(\r\x12\x35\n\tgame_mode\x18\x04 \x01(\x0e\x32\x0e.DOTA_GameMode:\x12\x44OTA_GAMEMODE_NONE\x12-\n\x07players\x18\x06 \x03(\x0b\x32\x1c.CMsgDOTAMatchMinimal.Player\x12.\n\x07tourney\x18\x07 \x01(\x0b\x32\x1d.CMsgDOTAMatchMinimal.Tourney\x12>\n\rmatch_outcome\x18\x08 \x01(\x0e\x32\x0e.EMatchOutcome:\x17k_EMatchOutcome_Unknown\x1a\x81\x01\n\x06Player\x12\x12\n\naccount_id\x18\x01 \x01(\r\x12\x0f\n\x07hero_id\x18\x02 \x01(\r\x12\r\n\x05kills\x18\x03 \x01(\r\x12\x0e\n\x06\x64\x65\x61ths\x18\x04 \x01(\r\x12\x0f\n\x07\x61ssists\x18\x05 \x01(\r\x12\r\n\x05items\x18\x06 \x03(\r\x12\x13\n\x0bplayer_slot\x18\x07 \x01(\r\x1a\xf3\x02\n\x07Tourney\x12\x11\n\tleague_id\x18\x01 \x01(\r\x12\x13\n\x0bseries_type\x18\x08 \x01(\r\x12\x13\n\x0bseries_game\x18\t \x01(\r\x12%\n\x1dweekend_tourney_tournament_id\x18\n \x01(\r\x12(\n weekend_tourney_season_trophy_id\x18\x0b \x01(\r\x12 \n\x18weekend_tourney_division\x18\x0c \x01(\r\x12#\n\x1bweekend_tourney_skill_level\x18\r \x01(\r\x12\x17\n\x0fradiant_team_id\x18\x02 \x01(\r\x12\x19\n\x11radiant_team_name\x18\x03 \x01(\t\x12\x19\n\x11radiant_team_logo\x18\x04 \x01(\x06\x12\x14\n\x0c\x64ire_team_id\x18\x05 \x01(\r\x12\x16\n\x0e\x64ire_team_name\x18\x06 \x01(\t\x12\x16\n\x0e\x64ire_team_logo\x18\x07 \x01(\x06\"\xcc\x01\n\x17\x43\x44OTAReplayDownloadInfo\x12$\n\x05match\x18\x01 \x01(\x0b\x32\x15.CMsgDOTAMatchMinimal\x12\r\n\x05title\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x0c\n\x04size\x18\x04 \x01(\r\x12\x0c\n\x04tags\x18\x05 \x03(\t\x12\x16\n\x0e\x65xists_on_disk\x18\x06 \x01(\x08\x1a\x33\n\tHighlight\x12\x11\n\ttimestamp\x18\x01 \x01(\r\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\"\x80\x01\n\rCMsgWatchGame\x12\x16\n\x0eserver_steamid\x18\x01 \x01(\x06\x12\x16\n\x0e\x63lient_version\x18\x02 \x01(\r\x12\x1c\n\x14watch_server_steamid\x18\x03 \x01(\x06\x12\x10\n\x08lobby_id\x18\x04 \x01(\x04\x12\x0f\n\x07regions\x18\x05 \x03(\r\"\x15\n\x13\x43MsgCancelWatchGame\"\xc9\x03\n\x15\x43MsgWatchGameResponse\x12J\n\x11watch_game_result\x18\x01 \x01(\x0e\x32&.CMsgWatchGameResponse.WatchGameResult:\x07PENDING\x12\x1d\n\x15source_tv_public_addr\x18\x02 \x01(\r\x12\x1e\n\x16source_tv_private_addr\x18\x03 \x01(\r\x12\x16\n\x0esource_tv_port\x18\x04 \x01(\r\x12\x1b\n\x13game_server_steamid\x18\x05 \x01(\x06\x12\x1c\n\x14watch_server_steamid\x18\x06 \x01(\x06\x12#\n\x1bwatch_tv_unique_secret_code\x18\x07 \x01(\x06\"\xac\x01\n\x0fWatchGameResult\x12\x0b\n\x07PENDING\x10\x00\x12\t\n\x05READY\x10\x01\x12\x16\n\x12GAMESERVERNOTFOUND\x10\x02\x12\x0f\n\x0bUNAVAILABLE\x10\x03\x12\r\n\tCANCELLED\x10\x04\x12\x17\n\x13INCOMPATIBLEVERSION\x10\x05\x12\x1d\n\x19MISSINGLEAGUESUBSCRIPTION\x10\x06\x12\x11\n\rLOBBYNOTFOUND\x10\x07\"=\n\x1e\x43MsgPartyLeaderWatchGamePrompt\x12\x1b\n\x13game_server_steamid\x18\x05 \x01(\x06\"\x82\x02\n\x14\x43\x44OTABroadcasterInfo\x12\x12\n\naccount_id\x18\x01 \x01(\r\x12\x17\n\x0fserver_steam_id\x18\x02 \x01(\x06\x12\x0c\n\x04live\x18\x03 \x01(\x08\x12\x19\n\x11team_name_radiant\x18\x04 \x01(\t\x12\x16\n\x0eteam_name_dire\x18\x05 \x01(\t\x12\x12\n\nstage_name\x18\x06 \x01(\t\x12\x13\n\x0bseries_game\x18\x07 \x01(\r\x12\x13\n\x0bseries_type\x18\x08 \x01(\r\x12$\n\x1cupcoming_broadcast_timestamp\x18\t \x01(\r\x12\x18\n\x10\x61llow_live_video\x18\n \x01(\x08\x42\x05H\x01\x90\x01\x00')
  ,
  dependencies=[dota__shared__enums__pb2.DESCRIPTOR,dota__gcmessages__common__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)



_CMSGWATCHGAMERESPONSE_WATCHGAMERESULT = _descriptor.EnumDescriptor(
  name='WatchGameResult',
  full_name='CMsgWatchGameResponse.WatchGameResult',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PENDING', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='READY', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GAMESERVERNOTFOUND', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNAVAILABLE', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANCELLED', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INCOMPATIBLEVERSION', index=5, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MISSINGLEAGUESUBSCRIPTION', index=6, number=6,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LOBBYNOTFOUND', index=7, number=7,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=3644,
  serialized_end=3816,
)
_sym_db.RegisterEnumDescriptor(_CMSGWATCHGAMERESPONSE_WATCHGAMERESULT)


_CSOURCETVGAMESMALL_PLAYER = _descriptor.Descriptor(
  name='Player',
  full_name='CSourceTVGameSmall.Player',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='CSourceTVGameSmall.Player.account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='hero_id', full_name='CSourceTVGameSmall.Player.hero_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=771,
  serialized_end=816,
)

_CSOURCETVGAMESMALL = _descriptor.Descriptor(
  name='CSourceTVGameSmall',
  full_name='CSourceTVGameSmall',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='activate_time', full_name='CSourceTVGameSmall.activate_time', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='deactivate_time', full_name='CSourceTVGameSmall.deactivate_time', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='server_steam_id', full_name='CSourceTVGameSmall.server_steam_id', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='lobby_id', full_name='CSourceTVGameSmall.lobby_id', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='league_id', full_name='CSourceTVGameSmall.league_id', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='lobby_type', full_name='CSourceTVGameSmall.lobby_type', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='game_time', full_name='CSourceTVGameSmall.game_time', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='delay', full_name='CSourceTVGameSmall.delay', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='spectators', full_name='CSourceTVGameSmall.spectators', index=8,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='game_mode', full_name='CSourceTVGameSmall.game_mode', index=9,
      number=10, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='average_mmr', full_name='CSourceTVGameSmall.average_mmr', index=10,
      number=11, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='team_name_radiant', full_name='CSourceTVGameSmall.team_name_radiant', index=11,
      number=15, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='team_name_dire', full_name='CSourceTVGameSmall.team_name_dire', index=12,
      number=16, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='team_logo_radiant', full_name='CSourceTVGameSmall.team_logo_radiant', index=13,
      number=24, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='team_logo_dire', full_name='CSourceTVGameSmall.team_logo_dire', index=14,
      number=25, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='sort_score', full_name='CSourceTVGameSmall.sort_score', index=15,
      number=17, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='last_update_time', full_name='CSourceTVGameSmall.last_update_time', index=16,
      number=18, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='radiant_lead', full_name='CSourceTVGameSmall.radiant_lead', index=17,
      number=19, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='radiant_score', full_name='CSourceTVGameSmall.radiant_score', index=18,
      number=20, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='dire_score', full_name='CSourceTVGameSmall.dire_score', index=19,
      number=21, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='players', full_name='CSourceTVGameSmall.players', index=20,
      number=22, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='building_state', full_name='CSourceTVGameSmall.building_state', index=21,
      number=23, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='weekend_tourney_tournament_id', full_name='CSourceTVGameSmall.weekend_tourney_tournament_id', index=22,
      number=26, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='weekend_tourney_division', full_name='CSourceTVGameSmall.weekend_tourney_division', index=23,
      number=27, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='weekend_tourney_skill_level', full_name='CSourceTVGameSmall.weekend_tourney_skill_level', index=24,
      number=28, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='weekend_tourney_bracket_round', full_name='CSourceTVGameSmall.weekend_tourney_bracket_round', index=25,
      number=29, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CSOURCETVGAMESMALL_PLAYER, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=94,
  serialized_end=816,
)


_CMSGCLIENTTOGCFINDTOPSOURCETVGAMES = _descriptor.Descriptor(
  name='CMsgClientToGCFindTopSourceTVGames',
  full_name='CMsgClientToGCFindTopSourceTVGames',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='search_key', full_name='CMsgClientToGCFindTopSourceTVGames.search_key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='league_id', full_name='CMsgClientToGCFindTopSourceTVGames.league_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='hero_id', full_name='CMsgClientToGCFindTopSourceTVGames.hero_id', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='start_game', full_name='CMsgClientToGCFindTopSourceTVGames.start_game', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='game_list_index', full_name='CMsgClientToGCFindTopSourceTVGames.game_list_index', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='lobby_ids', full_name='CMsgClientToGCFindTopSourceTVGames.lobby_ids', index=5,
      number=6, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=819,
  serialized_end=975,
)


_CMSGGCTOCLIENTFINDTOPSOURCETVGAMESRESPONSE = _descriptor.Descriptor(
  name='CMsgGCToClientFindTopSourceTVGamesResponse',
  full_name='CMsgGCToClientFindTopSourceTVGamesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='search_key', full_name='CMsgGCToClientFindTopSourceTVGamesResponse.search_key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='league_id', full_name='CMsgGCToClientFindTopSourceTVGamesResponse.league_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='hero_id', full_name='CMsgGCToClientFindTopSourceTVGamesResponse.hero_id', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='start_game', full_name='CMsgGCToClientFindTopSourceTVGamesResponse.start_game', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='num_games', full_name='CMsgGCToClientFindTopSourceTVGamesResponse.num_games', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='game_list_index', full_name='CMsgGCToClientFindTopSourceTVGamesResponse.game_list_index', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='game_list', full_name='CMsgGCToClientFindTopSourceTVGamesResponse.game_list', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='specific_games', full_name='CMsgGCToClientFindTopSourceTVGamesResponse.specific_games', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=978,
  serialized_end=1206,
)


_CMSGGCTOCLIENTTOPWEEKENDTOURNEYGAMES = _descriptor.Descriptor(
  name='CMsgGCToClientTopWeekendTourneyGames',
  full_name='CMsgGCToClientTopWeekendTourneyGames',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='live_games', full_name='CMsgGCToClientTopWeekendTourneyGames.live_games', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1208,
  serialized_end=1287,
)


_CMSGCLIENTTOGCTOPMATCHESREQUEST = _descriptor.Descriptor(
  name='CMsgClientToGCTopMatchesRequest',
  full_name='CMsgClientToGCTopMatchesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='hero_id', full_name='CMsgClientToGCTopMatchesRequest.hero_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='player_account_id', full_name='CMsgClientToGCTopMatchesRequest.player_account_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='team_id', full_name='CMsgClientToGCTopMatchesRequest.team_id', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1289,
  serialized_end=1383,
)


_CMSGCLIENTTOGCTOPLEAGUEMATCHESREQUEST = _descriptor.Descriptor(
  name='CMsgClientToGCTopLeagueMatchesRequest',
  full_name='CMsgClientToGCTopLeagueMatchesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1385,
  serialized_end=1424,
)


_CMSGCLIENTTOGCTOPFRIENDMATCHESREQUEST = _descriptor.Descriptor(
  name='CMsgClientToGCTopFriendMatchesRequest',
  full_name='CMsgClientToGCTopFriendMatchesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1426,
  serialized_end=1465,
)


_CMSGCLIENTTOGCMATCHESMINIMALREQUEST = _descriptor.Descriptor(
  name='CMsgClientToGCMatchesMinimalRequest',
  full_name='CMsgClientToGCMatchesMinimalRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='match_ids', full_name='CMsgClientToGCMatchesMinimalRequest.match_ids', index=0,
      number=1, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1467,
  serialized_end=1523,
)


_CMSGCLIENTTOGCMATCHESMINIMALRESPONSE = _descriptor.Descriptor(
  name='CMsgClientToGCMatchesMinimalResponse',
  full_name='CMsgClientToGCMatchesMinimalResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='matches', full_name='CMsgClientToGCMatchesMinimalResponse.matches', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='last_match', full_name='CMsgClientToGCMatchesMinimalResponse.last_match', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1525,
  serialized_end=1623,
)


_CMSGGCTOCLIENTTOPLEAGUEMATCHESRESPONSE = _descriptor.Descriptor(
  name='CMsgGCToClientTopLeagueMatchesResponse',
  full_name='CMsgGCToClientTopLeagueMatchesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='matches', full_name='CMsgGCToClientTopLeagueMatchesResponse.matches', index=0,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1625,
  serialized_end=1705,
)


_CMSGGCTOCLIENTTOPFRIENDMATCHESRESPONSE = _descriptor.Descriptor(
  name='CMsgGCToClientTopFriendMatchesResponse',
  full_name='CMsgGCToClientTopFriendMatchesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='matches', full_name='CMsgGCToClientTopFriendMatchesResponse.matches', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1707,
  serialized_end=1787,
)


_CMSGCLIENTTOGCFINDTOPMATCHES = _descriptor.Descriptor(
  name='CMsgClientToGCFindTopMatches',
  full_name='CMsgClientToGCFindTopMatches',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='start_game', full_name='CMsgClientToGCFindTopMatches.start_game', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='league_id', full_name='CMsgClientToGCFindTopMatches.league_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='hero_id', full_name='CMsgClientToGCFindTopMatches.hero_id', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='friend_id', full_name='CMsgClientToGCFindTopMatches.friend_id', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='friend_list', full_name='CMsgClientToGCFindTopMatches.friend_list', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='league_list', full_name='CMsgClientToGCFindTopMatches.league_list', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1790,
  serialized_end=1937,
)


_CMSGGCTOCLIENTFINDTOPLEAGUEMATCHESRESPONSE = _descriptor.Descriptor(
  name='CMsgGCToClientFindTopLeagueMatchesResponse',
  full_name='CMsgGCToClientFindTopLeagueMatchesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='start_game', full_name='CMsgGCToClientFindTopLeagueMatchesResponse.start_game', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='league_id', full_name='CMsgGCToClientFindTopLeagueMatchesResponse.league_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='hero_id', full_name='CMsgGCToClientFindTopLeagueMatchesResponse.hero_id', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='match_ids', full_name='CMsgGCToClientFindTopLeagueMatchesResponse.match_ids', index=3,
      number=4, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='matches', full_name='CMsgGCToClientFindTopLeagueMatchesResponse.matches', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1940,
  serialized_end=2092,
)


_CMSGSPECTATEFRIENDGAME = _descriptor.Descriptor(
  name='CMsgSpectateFriendGame',
  full_name='CMsgSpectateFriendGame',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='steam_id', full_name='CMsgSpectateFriendGame.steam_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2094,
  serialized_end=2136,
)


_CMSGSPECTATEFRIENDGAMERESPONSE = _descriptor.Descriptor(
  name='CMsgSpectateFriendGameResponse',
  full_name='CMsgSpectateFriendGameResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='server_steamid', full_name='CMsgSpectateFriendGameResponse.server_steamid', index=0,
      number=4, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2138,
  serialized_end=2194,
)


_CMSGDOTAMATCHMINIMAL_PLAYER = _descriptor.Descriptor(
  name='Player',
  full_name='CMsgDOTAMatchMinimal.Player',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='CMsgDOTAMatchMinimal.Player.account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='hero_id', full_name='CMsgDOTAMatchMinimal.Player.hero_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='kills', full_name='CMsgDOTAMatchMinimal.Player.kills', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='deaths', full_name='CMsgDOTAMatchMinimal.Player.deaths', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='assists', full_name='CMsgDOTAMatchMinimal.Player.assists', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='items', full_name='CMsgDOTAMatchMinimal.Player.items', index=5,
      number=6, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='player_slot', full_name='CMsgDOTAMatchMinimal.Player.player_slot', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2492,
  serialized_end=2621,
)

_CMSGDOTAMATCHMINIMAL_TOURNEY = _descriptor.Descriptor(
  name='Tourney',
  full_name='CMsgDOTAMatchMinimal.Tourney',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='league_id', full_name='CMsgDOTAMatchMinimal.Tourney.league_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='series_type', full_name='CMsgDOTAMatchMinimal.Tourney.series_type', index=1,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='series_game', full_name='CMsgDOTAMatchMinimal.Tourney.series_game', index=2,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='weekend_tourney_tournament_id', full_name='CMsgDOTAMatchMinimal.Tourney.weekend_tourney_tournament_id', index=3,
      number=10, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='weekend_tourney_season_trophy_id', full_name='CMsgDOTAMatchMinimal.Tourney.weekend_tourney_season_trophy_id', index=4,
      number=11, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='weekend_tourney_division', full_name='CMsgDOTAMatchMinimal.Tourney.weekend_tourney_division', index=5,
      number=12, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='weekend_tourney_skill_level', full_name='CMsgDOTAMatchMinimal.Tourney.weekend_tourney_skill_level', index=6,
      number=13, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='radiant_team_id', full_name='CMsgDOTAMatchMinimal.Tourney.radiant_team_id', index=7,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='radiant_team_name', full_name='CMsgDOTAMatchMinimal.Tourney.radiant_team_name', index=8,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='radiant_team_logo', full_name='CMsgDOTAMatchMinimal.Tourney.radiant_team_logo', index=9,
      number=4, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='dire_team_id', full_name='CMsgDOTAMatchMinimal.Tourney.dire_team_id', index=10,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='dire_team_name', full_name='CMsgDOTAMatchMinimal.Tourney.dire_team_name', index=11,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='dire_team_logo', full_name='CMsgDOTAMatchMinimal.Tourney.dire_team_logo', index=12,
      number=7, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2624,
  serialized_end=2995,
)

_CMSGDOTAMATCHMINIMAL = _descriptor.Descriptor(
  name='CMsgDOTAMatchMinimal',
  full_name='CMsgDOTAMatchMinimal',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='match_id', full_name='CMsgDOTAMatchMinimal.match_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='start_time', full_name='CMsgDOTAMatchMinimal.start_time', index=1,
      number=2, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='duration', full_name='CMsgDOTAMatchMinimal.duration', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='game_mode', full_name='CMsgDOTAMatchMinimal.game_mode', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='players', full_name='CMsgDOTAMatchMinimal.players', index=4,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tourney', full_name='CMsgDOTAMatchMinimal.tourney', index=5,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='match_outcome', full_name='CMsgDOTAMatchMinimal.match_outcome', index=6,
      number=8, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CMSGDOTAMATCHMINIMAL_PLAYER, _CMSGDOTAMATCHMINIMAL_TOURNEY, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2197,
  serialized_end=2995,
)


_CDOTAREPLAYDOWNLOADINFO_HIGHLIGHT = _descriptor.Descriptor(
  name='Highlight',
  full_name='CDOTAReplayDownloadInfo.Highlight',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='CDOTAReplayDownloadInfo.Highlight.timestamp', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='description', full_name='CDOTAReplayDownloadInfo.Highlight.description', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3151,
  serialized_end=3202,
)

_CDOTAREPLAYDOWNLOADINFO = _descriptor.Descriptor(
  name='CDOTAReplayDownloadInfo',
  full_name='CDOTAReplayDownloadInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='match', full_name='CDOTAReplayDownloadInfo.match', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='title', full_name='CDOTAReplayDownloadInfo.title', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='description', full_name='CDOTAReplayDownloadInfo.description', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='size', full_name='CDOTAReplayDownloadInfo.size', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tags', full_name='CDOTAReplayDownloadInfo.tags', index=4,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='exists_on_disk', full_name='CDOTAReplayDownloadInfo.exists_on_disk', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CDOTAREPLAYDOWNLOADINFO_HIGHLIGHT, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2998,
  serialized_end=3202,
)


_CMSGWATCHGAME = _descriptor.Descriptor(
  name='CMsgWatchGame',
  full_name='CMsgWatchGame',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='server_steamid', full_name='CMsgWatchGame.server_steamid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='client_version', full_name='CMsgWatchGame.client_version', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='watch_server_steamid', full_name='CMsgWatchGame.watch_server_steamid', index=2,
      number=3, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='lobby_id', full_name='CMsgWatchGame.lobby_id', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='regions', full_name='CMsgWatchGame.regions', index=4,
      number=5, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3205,
  serialized_end=3333,
)


_CMSGCANCELWATCHGAME = _descriptor.Descriptor(
  name='CMsgCancelWatchGame',
  full_name='CMsgCancelWatchGame',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3335,
  serialized_end=3356,
)


_CMSGWATCHGAMERESPONSE = _descriptor.Descriptor(
  name='CMsgWatchGameResponse',
  full_name='CMsgWatchGameResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='watch_game_result', full_name='CMsgWatchGameResponse.watch_game_result', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='source_tv_public_addr', full_name='CMsgWatchGameResponse.source_tv_public_addr', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='source_tv_private_addr', full_name='CMsgWatchGameResponse.source_tv_private_addr', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='source_tv_port', full_name='CMsgWatchGameResponse.source_tv_port', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='game_server_steamid', full_name='CMsgWatchGameResponse.game_server_steamid', index=4,
      number=5, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='watch_server_steamid', full_name='CMsgWatchGameResponse.watch_server_steamid', index=5,
      number=6, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='watch_tv_unique_secret_code', full_name='CMsgWatchGameResponse.watch_tv_unique_secret_code', index=6,
      number=7, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CMSGWATCHGAMERESPONSE_WATCHGAMERESULT,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3359,
  serialized_end=3816,
)


_CMSGPARTYLEADERWATCHGAMEPROMPT = _descriptor.Descriptor(
  name='CMsgPartyLeaderWatchGamePrompt',
  full_name='CMsgPartyLeaderWatchGamePrompt',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='game_server_steamid', full_name='CMsgPartyLeaderWatchGamePrompt.game_server_steamid', index=0,
      number=5, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3818,
  serialized_end=3879,
)


_CDOTABROADCASTERINFO = _descriptor.Descriptor(
  name='CDOTABroadcasterInfo',
  full_name='CDOTABroadcasterInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='CDOTABroadcasterInfo.account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='server_steam_id', full_name='CDOTABroadcasterInfo.server_steam_id', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='live', full_name='CDOTABroadcasterInfo.live', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='team_name_radiant', full_name='CDOTABroadcasterInfo.team_name_radiant', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='team_name_dire', full_name='CDOTABroadcasterInfo.team_name_dire', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='stage_name', full_name='CDOTABroadcasterInfo.stage_name', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='series_game', full_name='CDOTABroadcasterInfo.series_game', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='series_type', full_name='CDOTABroadcasterInfo.series_type', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='upcoming_broadcast_timestamp', full_name='CDOTABroadcasterInfo.upcoming_broadcast_timestamp', index=8,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='allow_live_video', full_name='CDOTABroadcasterInfo.allow_live_video', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3882,
  serialized_end=4140,
)

_CSOURCETVGAMESMALL_PLAYER.containing_type = _CSOURCETVGAMESMALL
_CSOURCETVGAMESMALL.fields_by_name['players'].message_type = _CSOURCETVGAMESMALL_PLAYER
_CMSGGCTOCLIENTFINDTOPSOURCETVGAMESRESPONSE.fields_by_name['game_list'].message_type = _CSOURCETVGAMESMALL
_CMSGGCTOCLIENTTOPWEEKENDTOURNEYGAMES.fields_by_name['live_games'].message_type = _CSOURCETVGAMESMALL
_CMSGCLIENTTOGCMATCHESMINIMALRESPONSE.fields_by_name['matches'].message_type = _CMSGDOTAMATCHMINIMAL
_CMSGGCTOCLIENTTOPLEAGUEMATCHESRESPONSE.fields_by_name['matches'].message_type = _CMSGDOTAMATCHMINIMAL
_CMSGGCTOCLIENTTOPFRIENDMATCHESRESPONSE.fields_by_name['matches'].message_type = _CMSGDOTAMATCHMINIMAL
_CMSGGCTOCLIENTFINDTOPLEAGUEMATCHESRESPONSE.fields_by_name['matches'].message_type = dota__gcmessages__common__pb2._CMSGDOTAMATCH
_CMSGDOTAMATCHMINIMAL_PLAYER.containing_type = _CMSGDOTAMATCHMINIMAL
_CMSGDOTAMATCHMINIMAL_TOURNEY.containing_type = _CMSGDOTAMATCHMINIMAL
_CMSGDOTAMATCHMINIMAL.fields_by_name['game_mode'].enum_type = dota__shared__enums__pb2._DOTA_GAMEMODE
_CMSGDOTAMATCHMINIMAL.fields_by_name['players'].message_type = _CMSGDOTAMATCHMINIMAL_PLAYER
_CMSGDOTAMATCHMINIMAL.fields_by_name['tourney'].message_type = _CMSGDOTAMATCHMINIMAL_TOURNEY
_CMSGDOTAMATCHMINIMAL.fields_by_name['match_outcome'].enum_type = dota__shared__enums__pb2._EMATCHOUTCOME
_CDOTAREPLAYDOWNLOADINFO_HIGHLIGHT.containing_type = _CDOTAREPLAYDOWNLOADINFO
_CDOTAREPLAYDOWNLOADINFO.fields_by_name['match'].message_type = _CMSGDOTAMATCHMINIMAL
_CMSGWATCHGAMERESPONSE.fields_by_name['watch_game_result'].enum_type = _CMSGWATCHGAMERESPONSE_WATCHGAMERESULT
_CMSGWATCHGAMERESPONSE_WATCHGAMERESULT.containing_type = _CMSGWATCHGAMERESPONSE
DESCRIPTOR.message_types_by_name['CSourceTVGameSmall'] = _CSOURCETVGAMESMALL
DESCRIPTOR.message_types_by_name['CMsgClientToGCFindTopSourceTVGames'] = _CMSGCLIENTTOGCFINDTOPSOURCETVGAMES
DESCRIPTOR.message_types_by_name['CMsgGCToClientFindTopSourceTVGamesResponse'] = _CMSGGCTOCLIENTFINDTOPSOURCETVGAMESRESPONSE
DESCRIPTOR.message_types_by_name['CMsgGCToClientTopWeekendTourneyGames'] = _CMSGGCTOCLIENTTOPWEEKENDTOURNEYGAMES
DESCRIPTOR.message_types_by_name['CMsgClientToGCTopMatchesRequest'] = _CMSGCLIENTTOGCTOPMATCHESREQUEST
DESCRIPTOR.message_types_by_name['CMsgClientToGCTopLeagueMatchesRequest'] = _CMSGCLIENTTOGCTOPLEAGUEMATCHESREQUEST
DESCRIPTOR.message_types_by_name['CMsgClientToGCTopFriendMatchesRequest'] = _CMSGCLIENTTOGCTOPFRIENDMATCHESREQUEST
DESCRIPTOR.message_types_by_name['CMsgClientToGCMatchesMinimalRequest'] = _CMSGCLIENTTOGCMATCHESMINIMALREQUEST
DESCRIPTOR.message_types_by_name['CMsgClientToGCMatchesMinimalResponse'] = _CMSGCLIENTTOGCMATCHESMINIMALRESPONSE
DESCRIPTOR.message_types_by_name['CMsgGCToClientTopLeagueMatchesResponse'] = _CMSGGCTOCLIENTTOPLEAGUEMATCHESRESPONSE
DESCRIPTOR.message_types_by_name['CMsgGCToClientTopFriendMatchesResponse'] = _CMSGGCTOCLIENTTOPFRIENDMATCHESRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientToGCFindTopMatches'] = _CMSGCLIENTTOGCFINDTOPMATCHES
DESCRIPTOR.message_types_by_name['CMsgGCToClientFindTopLeagueMatchesResponse'] = _CMSGGCTOCLIENTFINDTOPLEAGUEMATCHESRESPONSE
DESCRIPTOR.message_types_by_name['CMsgSpectateFriendGame'] = _CMSGSPECTATEFRIENDGAME
DESCRIPTOR.message_types_by_name['CMsgSpectateFriendGameResponse'] = _CMSGSPECTATEFRIENDGAMERESPONSE
DESCRIPTOR.message_types_by_name['CMsgDOTAMatchMinimal'] = _CMSGDOTAMATCHMINIMAL
DESCRIPTOR.message_types_by_name['CDOTAReplayDownloadInfo'] = _CDOTAREPLAYDOWNLOADINFO
DESCRIPTOR.message_types_by_name['CMsgWatchGame'] = _CMSGWATCHGAME
DESCRIPTOR.message_types_by_name['CMsgCancelWatchGame'] = _CMSGCANCELWATCHGAME
DESCRIPTOR.message_types_by_name['CMsgWatchGameResponse'] = _CMSGWATCHGAMERESPONSE
DESCRIPTOR.message_types_by_name['CMsgPartyLeaderWatchGamePrompt'] = _CMSGPARTYLEADERWATCHGAMEPROMPT
DESCRIPTOR.message_types_by_name['CDOTABroadcasterInfo'] = _CDOTABROADCASTERINFO

CSourceTVGameSmall = _reflection.GeneratedProtocolMessageType('CSourceTVGameSmall', (_message.Message,), dict(

  Player = _reflection.GeneratedProtocolMessageType('Player', (_message.Message,), dict(
    DESCRIPTOR = _CSOURCETVGAMESMALL_PLAYER,
    __module__ = 'dota_gcmessages_client_watch_pb2'
    # @@protoc_insertion_point(class_scope:CSourceTVGameSmall.Player)
    ))
  ,
  DESCRIPTOR = _CSOURCETVGAMESMALL,
  __module__ = 'dota_gcmessages_client_watch_pb2'
  # @@protoc_insertion_point(class_scope:CSourceTVGameSmall)
  ))
_sym_db.RegisterMessage(CSourceTVGameSmall)
_sym_db.RegisterMessage(CSourceTVGameSmall.Player)

CMsgClientToGCFindTopSourceTVGames = _reflection.GeneratedProtocolMessageType('CMsgClientToGCFindTopSourceTVGames', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCFINDTOPSOURCETVGAMES,
  __module__ = 'dota_gcmessages_client_watch_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientToGCFindTopSourceTVGames)
  ))
_sym_db.RegisterMessage(CMsgClientToGCFindTopSourceTVGames)

CMsgGCToClientFindTopSourceTVGamesResponse = _reflection.GeneratedProtocolMessageType('CMsgGCToClientFindTopSourceTVGamesResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCTOCLIENTFINDTOPSOURCETVGAMESRESPONSE,
  __module__ = 'dota_gcmessages_client_watch_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCToClientFindTopSourceTVGamesResponse)
  ))
_sym_db.RegisterMessage(CMsgGCToClientFindTopSourceTVGamesResponse)

CMsgGCToClientTopWeekendTourneyGames = _reflection.GeneratedProtocolMessageType('CMsgGCToClientTopWeekendTourneyGames', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCTOCLIENTTOPWEEKENDTOURNEYGAMES,
  __module__ = 'dota_gcmessages_client_watch_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCToClientTopWeekendTourneyGames)
  ))
_sym_db.RegisterMessage(CMsgGCToClientTopWeekendTourneyGames)

CMsgClientToGCTopMatchesRequest = _reflection.GeneratedProtocolMessageType('CMsgClientToGCTopMatchesRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCTOPMATCHESREQUEST,
  __module__ = 'dota_gcmessages_client_watch_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientToGCTopMatchesRequest)
  ))
_sym_db.RegisterMessage(CMsgClientToGCTopMatchesRequest)

CMsgClientToGCTopLeagueMatchesRequest = _reflection.GeneratedProtocolMessageType('CMsgClientToGCTopLeagueMatchesRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCTOPLEAGUEMATCHESREQUEST,
  __module__ = 'dota_gcmessages_client_watch_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientToGCTopLeagueMatchesRequest)
  ))
_sym_db.RegisterMessage(CMsgClientToGCTopLeagueMatchesRequest)

CMsgClientToGCTopFriendMatchesRequest = _reflection.GeneratedProtocolMessageType('CMsgClientToGCTopFriendMatchesRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCTOPFRIENDMATCHESREQUEST,
  __module__ = 'dota_gcmessages_client_watch_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientToGCTopFriendMatchesRequest)
  ))
_sym_db.RegisterMessage(CMsgClientToGCTopFriendMatchesRequest)

CMsgClientToGCMatchesMinimalRequest = _reflection.GeneratedProtocolMessageType('CMsgClientToGCMatchesMinimalRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCMATCHESMINIMALREQUEST,
  __module__ = 'dota_gcmessages_client_watch_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientToGCMatchesMinimalRequest)
  ))
_sym_db.RegisterMessage(CMsgClientToGCMatchesMinimalRequest)

CMsgClientToGCMatchesMinimalResponse = _reflection.GeneratedProtocolMessageType('CMsgClientToGCMatchesMinimalResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCMATCHESMINIMALRESPONSE,
  __module__ = 'dota_gcmessages_client_watch_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientToGCMatchesMinimalResponse)
  ))
_sym_db.RegisterMessage(CMsgClientToGCMatchesMinimalResponse)

CMsgGCToClientTopLeagueMatchesResponse = _reflection.GeneratedProtocolMessageType('CMsgGCToClientTopLeagueMatchesResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCTOCLIENTTOPLEAGUEMATCHESRESPONSE,
  __module__ = 'dota_gcmessages_client_watch_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCToClientTopLeagueMatchesResponse)
  ))
_sym_db.RegisterMessage(CMsgGCToClientTopLeagueMatchesResponse)

CMsgGCToClientTopFriendMatchesResponse = _reflection.GeneratedProtocolMessageType('CMsgGCToClientTopFriendMatchesResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCTOCLIENTTOPFRIENDMATCHESRESPONSE,
  __module__ = 'dota_gcmessages_client_watch_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCToClientTopFriendMatchesResponse)
  ))
_sym_db.RegisterMessage(CMsgGCToClientTopFriendMatchesResponse)

CMsgClientToGCFindTopMatches = _reflection.GeneratedProtocolMessageType('CMsgClientToGCFindTopMatches', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCFINDTOPMATCHES,
  __module__ = 'dota_gcmessages_client_watch_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientToGCFindTopMatches)
  ))
_sym_db.RegisterMessage(CMsgClientToGCFindTopMatches)

CMsgGCToClientFindTopLeagueMatchesResponse = _reflection.GeneratedProtocolMessageType('CMsgGCToClientFindTopLeagueMatchesResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCTOCLIENTFINDTOPLEAGUEMATCHESRESPONSE,
  __module__ = 'dota_gcmessages_client_watch_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCToClientFindTopLeagueMatchesResponse)
  ))
_sym_db.RegisterMessage(CMsgGCToClientFindTopLeagueMatchesResponse)

CMsgSpectateFriendGame = _reflection.GeneratedProtocolMessageType('CMsgSpectateFriendGame', (_message.Message,), dict(
  DESCRIPTOR = _CMSGSPECTATEFRIENDGAME,
  __module__ = 'dota_gcmessages_client_watch_pb2'
  # @@protoc_insertion_point(class_scope:CMsgSpectateFriendGame)
  ))
_sym_db.RegisterMessage(CMsgSpectateFriendGame)

CMsgSpectateFriendGameResponse = _reflection.GeneratedProtocolMessageType('CMsgSpectateFriendGameResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGSPECTATEFRIENDGAMERESPONSE,
  __module__ = 'dota_gcmessages_client_watch_pb2'
  # @@protoc_insertion_point(class_scope:CMsgSpectateFriendGameResponse)
  ))
_sym_db.RegisterMessage(CMsgSpectateFriendGameResponse)

CMsgDOTAMatchMinimal = _reflection.GeneratedProtocolMessageType('CMsgDOTAMatchMinimal', (_message.Message,), dict(

  Player = _reflection.GeneratedProtocolMessageType('Player', (_message.Message,), dict(
    DESCRIPTOR = _CMSGDOTAMATCHMINIMAL_PLAYER,
    __module__ = 'dota_gcmessages_client_watch_pb2'
    # @@protoc_insertion_point(class_scope:CMsgDOTAMatchMinimal.Player)
    ))
  ,

  Tourney = _reflection.GeneratedProtocolMessageType('Tourney', (_message.Message,), dict(
    DESCRIPTOR = _CMSGDOTAMATCHMINIMAL_TOURNEY,
    __module__ = 'dota_gcmessages_client_watch_pb2'
    # @@protoc_insertion_point(class_scope:CMsgDOTAMatchMinimal.Tourney)
    ))
  ,
  DESCRIPTOR = _CMSGDOTAMATCHMINIMAL,
  __module__ = 'dota_gcmessages_client_watch_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAMatchMinimal)
  ))
_sym_db.RegisterMessage(CMsgDOTAMatchMinimal)
_sym_db.RegisterMessage(CMsgDOTAMatchMinimal.Player)
_sym_db.RegisterMessage(CMsgDOTAMatchMinimal.Tourney)

CDOTAReplayDownloadInfo = _reflection.GeneratedProtocolMessageType('CDOTAReplayDownloadInfo', (_message.Message,), dict(

  Highlight = _reflection.GeneratedProtocolMessageType('Highlight', (_message.Message,), dict(
    DESCRIPTOR = _CDOTAREPLAYDOWNLOADINFO_HIGHLIGHT,
    __module__ = 'dota_gcmessages_client_watch_pb2'
    # @@protoc_insertion_point(class_scope:CDOTAReplayDownloadInfo.Highlight)
    ))
  ,
  DESCRIPTOR = _CDOTAREPLAYDOWNLOADINFO,
  __module__ = 'dota_gcmessages_client_watch_pb2'
  # @@protoc_insertion_point(class_scope:CDOTAReplayDownloadInfo)
  ))
_sym_db.RegisterMessage(CDOTAReplayDownloadInfo)
_sym_db.RegisterMessage(CDOTAReplayDownloadInfo.Highlight)

CMsgWatchGame = _reflection.GeneratedProtocolMessageType('CMsgWatchGame', (_message.Message,), dict(
  DESCRIPTOR = _CMSGWATCHGAME,
  __module__ = 'dota_gcmessages_client_watch_pb2'
  # @@protoc_insertion_point(class_scope:CMsgWatchGame)
  ))
_sym_db.RegisterMessage(CMsgWatchGame)

CMsgCancelWatchGame = _reflection.GeneratedProtocolMessageType('CMsgCancelWatchGame', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCANCELWATCHGAME,
  __module__ = 'dota_gcmessages_client_watch_pb2'
  # @@protoc_insertion_point(class_scope:CMsgCancelWatchGame)
  ))
_sym_db.RegisterMessage(CMsgCancelWatchGame)

CMsgWatchGameResponse = _reflection.GeneratedProtocolMessageType('CMsgWatchGameResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGWATCHGAMERESPONSE,
  __module__ = 'dota_gcmessages_client_watch_pb2'
  # @@protoc_insertion_point(class_scope:CMsgWatchGameResponse)
  ))
_sym_db.RegisterMessage(CMsgWatchGameResponse)

CMsgPartyLeaderWatchGamePrompt = _reflection.GeneratedProtocolMessageType('CMsgPartyLeaderWatchGamePrompt', (_message.Message,), dict(
  DESCRIPTOR = _CMSGPARTYLEADERWATCHGAMEPROMPT,
  __module__ = 'dota_gcmessages_client_watch_pb2'
  # @@protoc_insertion_point(class_scope:CMsgPartyLeaderWatchGamePrompt)
  ))
_sym_db.RegisterMessage(CMsgPartyLeaderWatchGamePrompt)

CDOTABroadcasterInfo = _reflection.GeneratedProtocolMessageType('CDOTABroadcasterInfo', (_message.Message,), dict(
  DESCRIPTOR = _CDOTABROADCASTERINFO,
  __module__ = 'dota_gcmessages_client_watch_pb2'
  # @@protoc_insertion_point(class_scope:CDOTABroadcasterInfo)
  ))
_sym_db.RegisterMessage(CDOTABroadcasterInfo)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('H\001\220\001\000'))
# @@protoc_insertion_point(module_scope)



"""
Only the most essential features to :class:`dota2.client.Dota2Client` are found here. Every other feature is inherited from
the :mod:`dota2.features` package and it's submodules.
"""

import logging
import gevent
import google.protobuf
from eventemitter import EventEmitter
from steam.core.msg import GCMsgHdrProto
from steam.client.gc import GameCoordinator
from steam.enums.emsg import EMsg
from steam.util import proto_fill_from_dict
from dota2.features import FeatureBase
from dota2.enums import EGCBaseClientMsg, EDOTAGCSessionNeed, GCConnectionStatus, ESourceEngine
from dota2.msg import get_emsg_enum, find_proto
from dota2.protobufs import gcsdk_gcmessages_pb2 as pb_gc
from dota2.protobufs import dota_gcmessages_client_pb2 as pb_gclient



class Dota2Client(GameCoordinator, FeatureBase):
    """
    :param steam_client: Instance of the steam client
    :type steam_client: :class:`steam.client.SteamClient`
    """
    _retry_welcome_loop = None
    verbose_debug = False  #: enable pretty print of messages in debug logging
    app_id = 570  #: main client app id
    current_jobid = 0
    ready = False  #: ``True`` when we have a session with GC
    connection_status = GCConnectionStatus.NO_SESSION  #: :class:`dota2.enums.GCConnectionStatus`

    @property
    def account_id(self):
        """
        Account ID of the logged in user in the steam client
        """
        return self.steam.steam_id.id

    @property
    def steam_id(self):
        """
        :class:`steam.steamid.SteamID` of the logged-in user in the steam client
        """
        return self.steam.steam_id

    def __init__(self, steam_client):
        GameCoordinator.__init__(self, steam_client, self.app_id)
        self._LOG = logging.getLogger(self.__class__.__name__)

        FeatureBase.__init__(self)

        self.steam.on('disconnected', self._handle_disconnect)
        self.steam.on(EMsg.ClientPlayingSessionState, self._handle_play_sess_state)

        # register GC message handles
        self.on(EGCBaseClientMsg.EMsgGCClientConnectionStatus, self._handle_conn_status)
        self.on(EGCBaseClientMsg.EMsgGCClientWelcome, self._handle_client_welcome)

    def __repr__(self):
        return "<%s(%s) %s>" % (self.__class__.__name__,
                                              repr(self.steam),
                                              repr(self.connection_status),
                                              )

    def _handle_play_sess_state(self, message):
        if self.ready and message.body.playing_app != self.app_id:
            self._set_connection_status(GCConnectionStatus.NO_SESSION)

    def _handle_disconnect(self):
        if self._retry_welcome_loop:
            self._retry_welcome_loop.kill()

        self._set_connection_status(GCConnectionStatus.NO_SESSION)

    def _handle_client_welcome(self, message):
        self._set_connection_status(GCConnectionStatus.HAVE_SESSION)

        # handle DOTAWelcome
        submessage = pb_gclient.CMsgDOTAWelcome()
        submessage.ParseFromString(message.game_data)

        if self.verbose_debug:
            self._LOG.debug("Got DOTAWelcome:\n%s" % str(submessage))
        else:
            self._LOG.debug("Got DOTAWelcome")

        self.emit('dota_welcome', submessage)

        for extra in submessage.extra_messages:
            self._process_gc_message(extra.id, GCMsgHdrProto(extra.id), extra.contents)


    def _handle_conn_status(self, message):
        self._set_connection_status(message.status)

    def _process_gc_message(self, emsg, header, payload):
        emsg = get_emsg_enum(emsg)
        proto = find_proto(emsg)

        if proto is None:
            self._LOG.error("Failed to parse: %s" % repr(emsg))
            return

        message = proto()
        message.ParseFromString(payload)

        if self.verbose_debug:
            self._LOG.debug("Incoming: %s\n%s\n---------\n%s" % (repr(emsg),
                                                              str(header),
                                                              str(message),
                                                              ))
        else:
            self._LOG.debug("Incoming: %s", repr(emsg))

        self.emit(emsg, message)

        if header.proto.job_id_target != 18446744073709551615:
            self.emit('job_%d' % header.proto.job_id_target, message)

    def _set_connection_status(self, status):
        prev_status = self.connection_status
        self.connection_status = GCConnectionStatus(status)

        if self.connection_status != prev_status:
            self.emit("connection_status", self.connection_status)

        if self.connection_status == GCConnectionStatus.HAVE_SESSION and not self.ready:
            self.ready = True
            self.emit('ready')
        elif self.connection_status != GCConnectionStatus.HAVE_SESSION and self.ready:
            self.ready = False
            self.emit('notready')

    def wait_msg(self, event, timeout=None, raises=None):
        """Wait for a message, similiar to :meth:`.wait_event`

        :param event: :class:`.EMsg' or job id
        :param timeout: seconds to wait before timeout
        :type timeout: :class:`int`
        :param raises: On timeout when ``False` returns :class:`None`, else raise :class:`gevent.Timeout`
        :type raises: :class:`bool`
        :return: returns a message or :class:`None`
        :rtype: :class:`None`, or `proto message`
        :raises: ``gevent.Timeout``
        """
        resp = self.wait_event(event, timeout, raises)

        if resp is not None:
            return resp[0]

    def send_job(self, *args, **kwargs):
        """
        Send a message as a job

        Exactly the same as :meth:`send`

        :return: jobid event identifier
        :rtype: :class:`str`

        """
        jobid = self.current_jobid = ((self.current_jobid + 1) % 10000) or 1
        self.remove_all_listeners('job_%d' % jobid)

        self._send(*args, jobid=jobid, **kwargs)

        return "job_%d" % jobid

    def send(self, emsg, data={}, proto=None):
        """
        Send a message

        :param emsg: Enum for the message
        :param data: data for the proto message
        :type data: :class:`dict`
        :param proto: (optional) manually specify protobuf, other it's detected based on ``emsg``
        """
        self._send(emsg, data, proto)

    def _send(self, emsg, data={}, proto=None, jobid=None):
        if not isinstance(data, dict):
            raise ValueError("data kwarg can only be a dict")

        if proto is None:
            proto = find_proto(emsg)

        if not issubclass(proto, google.protobuf.message.Message):
            raise ValueError("Unable to find proto for emsg, or proto kwarg is invalid")

        message = proto()
        proto_fill_from_dict(message, data)

        header = GCMsgHdrProto(emsg)

        if jobid is not None:
            header.proto.job_id_source = jobid

        if self.verbose_debug:
            str_message = ''
            str_header = str(header)
            str_body = str(message)

            if str_header:
                str_message += "-- header ---------\n%s\n" % str_header
            if str_body:
                str_message += "-- message --------\n%s\n" % str_body

            self._LOG.debug("Outgoing: %s\n%s" % (repr(emsg), str_message))
        else:
            self._LOG.debug("Outgoing: %s", repr(emsg))

        GameCoordinator.send(self, header, message.SerializeToString())

    def _knock_on_gc(self):
            n = 1

            while True:
                if not self.ready:
                    self.send(EGCBaseClientMsg.EMsgGCClientHello, {
                        'client_session_need': EDOTAGCSessionNeed.UserInUINeverConnected,
                        'engine': ESourceEngine.ESE_Source2,
                        })

                    self.wait_event('ready', timeout=3 + (2**n))
                    n = min(n + 1, 4)

                else:
                    self.wait_event('notready')
                    n = 1
                    gevent.sleep(1)

    def launch(self):
        """
        Launch Dota 2 and establish connection with the game coordinator

        ``ready`` event will fire when the session is ready.
        If the session is lost ``notready`` event will fire.
        Alternatively, ``connection_status`` event can be monitored for changes.
        """
        if not self.steam.logged_on:
            self.steam.wait_event('logged_on')

        if not self._retry_welcome_loop and self.app_id not in self.steam.current_games_played:
            self.steam.games_played(self.steam.current_games_played + [self.app_id])
            self._retry_welcome_loop = gevent.spawn(self._knock_on_gc)

    def exit(self):
        """
        Close connection to Dota 2's game coordinator
        """
        if self._retry_welcome_loop:
            self._retry_welcome_loop.kill()

        if self.app_id in self.steam.current_games_played:
            self.steam.games_played(filter(lambda x: x != self.app_id, self.steam.current_games_played))

        self._set_connection_status(GCConnectionStatus.NO_SESSION)



__version__ = "0.2.5"
__author__ = "Rossen Georgiev"

version_info = (0, 2, 5)


# proxy object
# avoids importing dota2.enums unless it's needed
class Dota2Client(object):
    def __new__(cls, *args, **kwargs):
        from dota2.client import Dota2Client as D2C
        return D2C(*args, **kwargs)



from dota2.features.player import Player
from dota2.features.match import Match
from dota2.features.lobby import Lobby
from dota2.features.sharedobjects import SOBase
from dota2.features.party import Party


class FeatureBase(Player, Match, Lobby, Party, SOBase):
    """
    This object is used to all high level functionality to Dota2Client.
    The features are seperated into submodules with a single class.
    """
    pass
